@@ -4,18 +4,14 @@
 #include <QWidget>
 #include <QPixmap>
 
+#include "utils.h"
+
+
+
+
 class QPaintEvent;
-class QSvgRenderer;
 class QResizeEvent;
 
-typedef enum {
-
-    LuxusUnits_Lux = 0,
-    LuxusUnits_CD_m2,
-    LuxusUnits_CD_ft,
-    LuxusUnits_EV_100
-
-} LuxusUnits;
 
 class LuxWidget : public QWidget
 {
@@ -36,11 +32,7 @@ private:
     int timerId;
     LuxusUnits currentUnit;
 
-    int getLux();
-    bool detectSB();
 
-    qreal log2(qreal);
-    QPair<int,int> Lux2EV(int);
 };
 
 #endif
